/*
 *  hbook_interface.h  --
 *	Declare interface to HBOOK.
 *
 *  Original: 12-Jan-1996 15:55
 *
 *  Author:   Maarten Ballintijn <Maarten.Ballintijn@cern.ch>
 *
 *  $Id: hbook_interface.h,v 1.9 1996/08/07 10:10:41 dinofm Exp $
 *
 *  $Log: hbook_interface.h,v $
 *  Revision 1.9  1996/08/07 10:10:41  dinofm
 *  The HLOGPF Fortran wrapper used to declare the first parameter as PSTRING
 *  instead than STRING. Since the h_load_nt function calls the HLOGPF wrapper
 *  passing a string literal, the OpenVMS implementation of cfortran.h
 *  probably tried to expand a literal, causing an "Access violation"
 *  exception raising. The parameter is now properly declared as STRING.
 *
 *  Revision 1.8  1996/05/12 15:13:51  maartenb
 *  - Replaced the handling of variables. The handling of variables is now
 *  fully dynamic and there is no other limit than the commonblocks to the
 *  number of var's in a query.
 *
 *  Revision 1.7  1996/04/23 18:38:03  maartenb
 *  - Add RCS keywords
 *
 *
 */

#ifndef CERN_HBOOK_INTERFACE
#define CERN_HBOOK_INTERFACE

#include	"cfortran.h"


#define HBALLOC(IDN,CHDIR,VAR,BLOCK,ITYPE,ISIZE,IFIRST,NELEM,IBASE,IOFF,NUSE)\
	CCALLSFSUB11(HBALLOC,hballoc,INT,STRING,STRING,STRING,INT,INT,INT,INT,INTV,PINT,PINT,IDN,CHDIR,VAR,BLOCK,ITYPE,ISIZE,IFIRST,NELEM,IBASE,IOFF,NUSE)


#define	HBFREE(LUN) \
	CCALLSFSUB1(HBFREE,hbfree,INT,LUN)


#define HBINIT1(IFLAG)	\
	CCALLSFSUB1(HBINIT1,hbinit1,INT,IFLAG)


#define HBOOK1(A1,A2,A3,A4,A5,A6) \
	CCALLSFSUB6(HBOOK1,hbook1,INT,STRING,INT,FLOAT,FLOAT,FLOAT,A1,A2,A3,A4,A5,A6)


#define HBOOK2(A1,A2,A3,A4,A5,A6,A7,A8,A9) \
	CCALLSFSUB9(HBOOK2,hbook2,INT,STRING,INT,FLOAT,FLOAT,INT,FLOAT,FLOAT,FLOAT,A1,A2,A3,A4,A5,A6,A7,A8,A9)


#define HBOOKN(A1,A2,A3,A4,A5,A6) \
	CCALLSFSUB6(HBOOKN,hbookn,INT,STRING,INT,STRING,INT,STRINGV,A1,A2,A3,A4,A5,A6)


#define HBPROF(A1,A2,A3,A4,A5,A6,A7,A8) \
	CCALLSFSUB8(HBPROF,hbprof,INT,STRING,INT,FLOAT,FLOAT,FLOAT,FLOAT,STRING,A1,A2,A3,A4,A5,A6,A7,A8)


#define HBNAME(A1,A2,A3,A4) \
	CCALLSFSUB4(HBNAME,hbname,INT,STRING,INTV,STRING,A1,A2,A3,A4)


#define HBNT(IDD,CHTITL,CHOPT1) \
	CCALLSFSUB3(HBNT,hbnt,INT,STRING,STRING,IDD,CHTITL,CHOPT1)


#define HBSET(A1,A2,A3) \
	CCALLSFSUB3(HBSET,hbset,STRING,INT,PINT,A1,A2,A3)


#define HROPEN(A1,A2,A3,A4,A5,A6) \
	CCALLSFSUB6(HROPEN,hropen,INT,STRING,STRING,STRING,PINT,PINT,A1,A2,A3,A4,A5,A6)


#define HCDIR(A1,A2) \
	CCALLSFSUB2(HCDIR,hcdir,PSTRING,STRING,A1,A2)


#define	HDCOFL() \
	CCALLSFSUB0(HDCOFL,hdcofl)


#define HDELET(A1) \
	CCALLSFSUB1(HDELET,hdelet,INT,A1)


PROTOCCALLSFFUN1(LOGICAL,HEXIST,hexist,INT)

#define HEXIST(A2) \
	CCALLSFFUN1(HEXIST,hexist,INT,A2)


#define HFN(A1,A2) \
	CCALLSFSUB2(HFN,hfn,INT,FLOATV,A1,A2)


#define HF1N(ID,X,W,NEVT) \
	CCALLSFSUB4(HF1N,hf1n,INT,FLOATV,FLOATV,INT,ID,X,W,NEVT)


#define HFILL(A1,A2,A3,A4) \
	CCALLSFSUB4(HFILL,hfill,INT,FLOAT,FLOAT,FLOAT,A1,A2,A3,A4)


#define HFNT(A1) \
	CCALLSFSUB1(HFNT,hfnt,INT,A1)


#define HGNF(A1,A2,A3,A4) \
	CCALLSFSUB4(HGNF,hgnf,INT,INT,PFLOAT,PINT,A1,A2,A3,A4)


#define HGNPAR(A1,A2) \
	CCALLSFSUB2(HGNPAR,hgnpar,INT,STRING,A1,A2)

/* fix the element length of VAR to 32 */
#define hgntbf_ELEMS_2		ZTRINGV_ARGS(4)
#define hgntbf_ELEMLEN_2	ZTRINGV_NUM(32)
#define HGNTBF(IDN,VAR,IOFFST,NVAR,IDNEVT,IERROR)\
	CCALLSFSUB6(HGNTBF,hgntbf,INT,ZTRINGV,INTV,INT,INT,PINT,IDN,VAR,IOFFST,NVAR,IDNEVT,IERROR)


#define HGNTF(A1,A2,A3) \
	CCALLSFSUB3(HGNTF,hgntf,INT,INT,PINT,A1,A2,A3)


#define HGIVEN(ID1,CHTITL,NVAR,TAGS,RLOW,RHIGH) \
	CCALLSFSUB6(HGIVEN,hgiven,INT,PSTRING,PINT,PSTRINGV,FLOATV,FLOATV,\
			ID1,CHTITL,NVAR,TAGS,RLOW,RHIGH) \


#define HGTDIR(CHDIR) \
	CCALLSFSUB1(HGTDIR,hgtdir,PSTRING,CHDIR)


#define HLABEL(ID,NLAB,CLAB,CHOPT)  CCALLSFSUB4(HLABEL,hlabel,INT,INT,STRINGV,STRING,ID,NLAB,CLAB,CHOPT)


PROTOCCALLSFFUN2(LOGICAL,HLABEQ,hlabeq,INT,STRING)

#define HLABEQ(IDD,CHOPT) \
	CCALLSFFUN2(HLABEQ,hlabeq,INT,STRING,IDD,CHOPT)


PROTOCCALLSFFUN2(INT,HLABNB,hlabnb,INT,STRING)

#define HLABNB(IDD,CHOPT) \
	CCALLSFFUN2(HLABNB,hlabnb,INT,STRING,IDD,CHOPT)


#define	HLGNXT(IDD,IPOS,CHLAB,CHOPT) \
	CCALLSFSUB4(HLGNXT,hlgnxt,INT,INT,PSTRING,STRING,IDD,IPOS,CHLAB,CHOPT)


#define HLIMIT(A1) \
	CCALLSFSUB1(HLIMIT,hlimit,INT,A1)


#define HLOGPF(CHHEAD,ISTAT) \
	CCALLSFSUB2(HLOGPF,hlogpf,STRING,PINT,CHHEAD,ISTAT)


#define HNOENT(A1,A2) \
	CCALLSFSUB2(HNOENT,hnoent,INT,PINT,A1,A2)


#define HNTDIM(TVAR,NVDIM,IVDIM,MXVDIM) \
	CCALLSFSUB4(HNTDIM,hntdim,STRING,PINT,INTV,INT,\
		TVAR,NVDIM,IVDIM,MXVDIM) \


#define HNTGET(ID1,TVAR,INDX,ITYPE,ISIZE,IELEM,IER)\
	CCALLSFSUB7(HNTGET,hntget,INT,STRING,PINT,PINT,PINT,PINT,PINT,ID1,TVAR,INDX,ITYPE,ISIZE,IELEM,IER)


#define HNTGETI(ID1,ICOM,INDX,TVAR,ITYPE,ISIZE,IELEM,IER) \
	CCALLSFSUB8(HNTGETI,hntgeti,INT,INT,INT,PSTRING,PINT,PINT,PINT,PINT,ID1,ICOM,INDX,TVAR,ITYPE,ISIZE,IELEM,IER)


PROTOCCALLSFFUN1(LOGICAL,HNTNEW,hntnew,INT)

#define HNTNEW(IDN) \
	CCALLSFFUN1(HNTNEW,hntnew,INT,IDN)


#define HNTRNG(TVAR,ILOW,IUP,IERR) \
	CCALLSFSUB4(HNTRNG,hntrng,STRING,PINT,PINT,PINT,\
		TVAR,ILOW,IUP,IERR) \


#define HNTVAR(ID1,IVAR,CHTAG,BLOCK,NSUB,ITYPE,ISIZE,IELEM) \
	CCALLSFSUB8(HNTVAR,hntvar,INT,INT,PSTRING,PSTRING,PINT,PINT,PINT,PINT,ID1,IVAR,CHTAG,BLOCK,NSUB,ITYPE,ISIZE,IELEM)


#define HRNGPF(NSLAV,MYSID,IFIRST,ITO) \
	CCALLSFSUB4(HRNGPF,hrngpf,INT,INT,PINT,PINT,NSLAV,MYSID,IFIRST,ITO)


#define HRESET(A1,A2) \
	CCALLSFSUB2(HRESET,hreset,INT,STRING,A1,A2)


#define HRIN(A1,A2,A3) \
	CCALLSFSUB3(HRIN,hrin,INT,INT,INT,A1,A2,A3)


#define HROUT(IDD,ICYCLE,CHOPT) \
	CCALLSFSUB3(HROUT,hrout,INT,PINT,STRING,IDD,ICYCLE,CHOPT)


#define	HVXIST(TVAR,BLOCK,CIVAR,ITYPE,ISIZE,IELEM) \
	CCALLSFSUB6(HVXIST,hvxist,STRING,PSTRING,PSTRING,PINT,PINT,PINT,\
		TVAR,BLOCK,CIVAR,ITYPE,ISIZE,IELEM) \


#endif	/*	CERN_HBOOK_INTERFACE	*/
